#!/usr/bin/python3
#-----------------------------------------------------------------------------
# Project    : Tutoriels - Conception de circuits intégrés analogiques
#-----------------------------------------------------------------------------
# File       : sync.py
# Authors    : Mickael Fiorentino <mickael.fiorentino@polymtl.ca>
# Lab        : GRM - Polytechnique Montréal
# Date       : <2019-07-24 Wed>
#-----------------------------------------------------------------------------
# Description: Synchronisation de la documentation sur le Wiki du GRM
#              - Interface à partir de l'API XML-RPC de DokuWiki
#              --> module dokuwiki: https://python-dokuwiki.readthedocs.io
#-----------------------------------------------------------------------------
import dokuwiki
import argparse

# Arguments
parser = argparse.ArgumentParser()
parser.add_argument("login", type=str, help="Nom d'utilisateur sur le Wiki du GRM")
parser.add_argument("passwd", type=str, help="Mot de passe sur le Wiki du GRM")
args = parser.parse_args()

# Parameters
username  = args.login
password  = args.passwd
wiki_url  = 'https://intranet.grm.polymtl.ca/wiki'
namespace = ':tutos:inverseur:'
img_dir   = 'img'
wiki_dir  = 'wiki'

# Login                                                   
try:
    wiki = dokuwiki.DokuWiki(wiki_url, username, password, cookieAuth=True)
except (DokuWikiError, Exception) as err:
    print('unable to connect: %s' % err)

# Backup pages 
pages_list = wiki.pages.list(namespace)
for p in pages_list:
    page = wiki.pages.get(p['id'])
    name = wiki_dir + '/' + p['id'].split(':')[-1] + '.dwiki'
    with open(name, 'w') as f:
        f.write(page)

# Backup Media
media_list = wiki.medias.list(namespace)
for m in media_list:
    name = m['id'].split(':')[-1]
    wiki.medias.get(m['id'], dirpath=img_dir, filename=name, overwrite=True)
